using System;
using System.Xml;

namespace stunnware.CRM.Fetch {
   /// <summary>
   /// Summary description for CrmEntity.
   /// </summary>
   public class CrmEntity {

      private XmlNode _entityNode;
      private string[] _attributeNames;

      public CrmEntity(XmlNode entityNode) {
         _entityNode = entityNode;
      }

      public string Xml {
         get {
            return _entityNode.OuterXml;
         }
      }

      public int AttributeCount {
         get {
            return _entityNode.ChildNodes.Count;
         }
      }

      public string[] AttributeNames {
         get {
            if (_attributeNames == null) {

               _attributeNames = new string[AttributeCount];
               int index = 0;

               foreach(XmlNode node in _entityNode.ChildNodes) {
                  _attributeNames[index++] = node.Name;
               }
            }

            return _attributeNames;
         }
      }

      public object this[string attributeName] {
         get {
            XmlNode node = _entityNode.SelectSingleNode(attributeName);
            return (node == null) ? null : node.InnerText;
         }
      }

      public object this[string attributeName, string property] {
         get {
            XmlNode node = _entityNode.SelectSingleNode(attributeName);

            if (node != null) {
               XmlAttribute attr = node.Attributes[property];
               return (attr == null) ? null : attr.InnerText;
            }

            else {
               return null;
            }         
         }
      }

      public string GetAttributeDisplayValue(string attributeName) {

         XmlNode node = _entityNode.SelectSingleNode(attributeName);

         if (node != null) {

            XmlAttribute attr = node.Attributes["name"];

            if (attr != null) {
               return attr.InnerText;
            }

            attr = node.Attributes["formattedvalue"];

            if (attr != null) {
               return attr.InnerText;
            }

            XmlAttribute date = node.Attributes["date"];
            XmlAttribute time = node.Attributes["time"];

            if ((date != null) && (time != null)) {
               return date.InnerText + " " + time.InnerText;
            }

            if (date != null) {
               return date.InnerText;
            }

            if (time != null) {
               return time.InnerText;
            }

            return node.InnerText;
         }

         else {
            return null;
         }         

      }
   }
}